@@ -28,13 +28,13 @@ __package_name__ = "geotribu"
 __summary__ = "Des outils pour faciliter les tâches récurrentes des contributeur/ices de Geotribu."
 __title__ = "Geotribu Toolbelt"
 __title_clean__ = "".join(e for e in __title__ if e.isalnum())
-__uri_homepage__ = "https://geotribu.github.io/cli/"
+__uri_homepage__ = "https://cli.geotribu.fr/"
 __uri_repository__ = "https://github.com/geotribu/cli/"
 __uri_tracker__ = f"{__uri_repository__}issues/"
 
 __uri__ = __uri_repository__
 
-__version__ = "0.4.0"
+__version__ = "0.6.0"
 __version_info__ = tuple(
     [
         int(num) if num.isdigit() else num
